@@ -49,13 +49,13 @@ class GenomeViz:
         tick_track_ratio : float, optional
             Tick track ratio
         track_spines : bool, optional
-            Display track spines
+            If True, display track spines
         tick_style : Optional[str], optional
             Tick style (`axis`|`bar`)
         plot_size_thr : float, optional
-            Plot feature size threshold.
-            If `plot_size_thr=0.0005` and `max_track_size=4.0Mb`, feature smaller than
-            `max_track_size * plot_size_thr=2.0Kb` are not plotted.
+            Plot feature, link size threshold.
+            If `plot_size_thr=0.0005` and `max_track_size=4.0Mb`, feature, link
+            smaller than `max_track_size * plot_size_thr=2.0Kb` are not plotted.
         tick_labelsize : int, optional
             Tick label size
         """
@@ -152,6 +152,7 @@ class GenomeViz:
         name: str,
         size: int,
         labelsize: int = 20,
+        labelcolor: str = "black",
         labelmargin: float = 0.01,
         linewidth: int = 1,
         linecolor: str = "grey",
@@ -170,6 +171,8 @@ class GenomeViz:
             Track size
         labelsize : int, optional
             Track label size
+        labelcolor : str, optional
+            Track label color
         labelmargin : flaot, optional
             Track label margin
         linewidth : int, optional
@@ -186,7 +189,7 @@ class GenomeViz:
             Feature track
         """
         # Check specified track name is unique or not
-        if name in [t.name for t in self.get_tracks(subtrack=True)]:
+        if name in [t.name for t in self.get_tracks()]:
             err_msg = f"track.name='{name}' is already exists."
             raise ValueError(err_msg)
         # Add link track between feature tracks
@@ -201,6 +204,7 @@ class GenomeViz:
             name,
             size,
             labelsize,
+            labelcolor,
             labelmargin,
             linewidth,
             linecolor,
@@ -294,13 +298,11 @@ class GenomeViz:
         track : Track
             Target track
         """
-        track_name2track = {}
-        for track in self.get_tracks(subtrack=True):
-            track_name2track[track.name] = track
-        if track_name not in track_name2track.keys():
+        name2track = {t.name: t for t in self.get_tracks()}
+        if track_name not in name2track.keys():
             err_msg = f"track.name='{track_name}' is not found."
             raise ValueError(err_msg)
-        return track_name2track[track_name]
+        return name2track[track_name]
 
     def get_tracks(self, subtrack: bool = False) -> List[Track]:
         """Get tracks
@@ -308,7 +310,7 @@ class GenomeViz:
         Parameters
         ----------
         subtrack : bool, optional
-            Include feature subtrack or not
+            If True, include feature subtracks
 
         Returns
         -------
@@ -396,6 +398,7 @@ class GenomeViz:
         )
 
         # Plot each track
+        plot_length_thr = max_track_size * self.plot_size_thr
         for idx, track in enumerate(self.get_tracks(subtrack=True)):
             # Create new track subplot
             xlim, ylim = (0, max_track_size), track.ylim
@@ -420,7 +423,7 @@ class GenomeViz:
 
                 for feature in [f + track_offset for f in track.features]:
                     # Don't plot too small feature (To reduce drawing time)
-                    if feature.length < max_track_size * self.plot_size_thr:
+                    if feature.length < plot_length_thr:
                         continue
                     # Plot feature patch & label text
                     feature.plot_feature(ax, max_track_size, ylim)
@@ -432,6 +435,10 @@ class GenomeViz:
 
             elif isinstance(track, LinkTrack):
                 for link in track.links:
+                    # Don't plot too small link (To reduce drawing time)
+                    length1, length2 = link.track_length1, link.track_length2
+                    if 0 < length1 < plot_length_thr or 0 < length2 < plot_length_thr:
+                        continue
                     link = link.add_offset(self._track_name2offset)
                     link.plot_link(ax, ylim)
 
@@ -440,11 +447,13 @@ class GenomeViz:
                     ax.xaxis.set_major_locator(MaxNLocator(10, steps=[1, 2, 5, 10]))
                     ax.xaxis.set_major_formatter(track.tick_formatter)
                 elif self.tick_style == "bar":
+                    avg_height_ratio = sum(height_ratios) / len(height_ratios)
+                    track.height_scale = avg_height_ratio / self.tick_track_ratio
                     ymin, ycenter, ymax = track.ymin, track.ycenter, track.ymax
-                    common_opts = {"colors": "black", "linewidth": 1, "clip_on": False}
-                    ax.hlines(ycenter, track.xmin, track.xmax, **common_opts)
-                    ax.vlines(track.xmin, ymin, ymax, **common_opts)
-                    ax.vlines(track.xmax, ymin, ymax, **common_opts)
+                    line_kws = {"colors": "black", "linewidth": 1, "clip_on": False}
+                    ax.hlines(ycenter, track.xmin, track.xmax, **line_kws)
+                    ax.vlines(track.xmin, ymin, ymax, **line_kws)
+                    ax.vlines(track.xmax, ymin, ymax, **line_kws)
                     ax.text(**track.scalebar_text_params)
 
             else:
@@ -483,7 +492,7 @@ class GenomeViz:
         Parameters
         ----------
         detail : bool, optional
-            Print detail or not. If True, detail 'feature' and 'link' are output.
+            If True, also output feature and link details
         """
         for idx, track in enumerate(self.get_tracks(subtrack=True), 1):
             # Print track common info
@@ -566,12 +575,12 @@ class GenomeViz:
             nearly_white = to_nearly_white(color)
             cmap = colors.LinearSegmentedColormap.from_list("m", (nearly_white, color))
             norm = colors.Normalize(vmin=vmin, vmax=vmax)
-            cb_props = {"orientation": "vertical", "ticks": []}
-            cb = ColorbarBase(cbar_ax, cmap=cmap, norm=norm, alpha=alpha, **cb_props)
+            cb_kws = {"orientation": "vertical", "ticks": []}
+            cb = ColorbarBase(cbar_ax, cmap=cmap, norm=norm, alpha=alpha, **cb_kws)
             if cnt == len(bar_colors) - 1:
                 ticks = [vmin, vmax]
                 labels = [f"{t}%" for t in ticks]
                 cb.set_ticks(ticks, labels=labels, fontsize=tick_labelsize)
                 x, y = 2.0, (vmin + vmax) / 2
-                text_props = {"rotation": 90, "ha": "left", "va": "center"}
-                cbar_ax.text(x, y, bar_label, size=bar_labelsize, **text_props)
+                text_kws = {"rotation": 90, "ha": "left", "va": "center"}
+                cbar_ax.text(x, y, bar_label, size=bar_labelsize, **text_kws)
