@@ -27,7 +27,7 @@ class Link:
     vmin: float = 0
     vmax: float = 100
     curve: bool = False
-    size_ratio: float = 0.9
+    size_ratio: float = 1.0
     patch_kws: Optional[Dict[str, Any]] = None
 
     def __post_init__(self):
@@ -51,6 +51,16 @@ class Link:
                 err_msg += f" (value={self.v}, vmin={self.vmin}, vmax={self.vmax})"
                 raise ValueError(err_msg)
 
+    @property
+    def track_length1(self) -> int:
+        """Track length1"""
+        return abs(self.track_end1 - self.track_start1)
+
+    @property
+    def track_length2(self) -> int:
+        """Track length2"""
+        return abs(self.track_end2 - self.track_start2)
+
     def plot_link(self, ax: Axes, ylim: Tuple[float, float] = (-1.0, 1.0)) -> None:
         """Plot link
 
@@ -97,9 +107,11 @@ class Link:
             Patch keyword arguments dict
         """
         patch_kws = {} if self.patch_kws is None else self.patch_kws
+        lw = 1 if self.track_length1 == self.track_length2 == 0 else 0
         return {
             "fc": self.color,
-            "lw": 0,
+            "ec": "grey",
+            "lw": lw,
             **patch_kws,
         }
 
