@@ -108,6 +108,7 @@ class FeatureTrack(Track):
         name: str,
         size: int,
         labelsize: int = 20,
+        labelcolor: str = "black",
         labelmargin: float = 0.01,
         linewidth: int = 1,
         linecolor: str = "black",
@@ -123,6 +124,8 @@ class FeatureTrack(Track):
             Track size
         labelsize : int, optional
             Track label size
+        labelcolor : str, optional
+            Track label color
         labelmargin : float, optional
             Track label margin
         linewidth : int, optional
@@ -135,6 +138,7 @@ class FeatureTrack(Track):
             Track height ratio
         """
         super().__init__(name, size, labelsize, spines, ratio)
+        self.labelcolor = labelcolor
         self.labelmargin = labelmargin
         self.linewidth = linewidth
         self.linecolor = linecolor
@@ -152,26 +156,50 @@ class FeatureTrack(Track):
         return {
             "s": self.name,
             "fontsize": self.labelsize,
+            "color": self.labelcolor,
             "ha": "right",
             "va": "center",
         }
 
-    def add_subtrack(self, ratio: float = 1.0) -> None:
+    def add_subtrack(self, name: Optional[str] = None, ratio: float = 1.0) -> None:
         """Add subtrack to feature track
 
         Parameters
         ----------
+        name : str, optional
+            Subtrack name. If None, subtrack name is automatically set.
         ratio : float, optional
             Subtrack size ratio to feature track
         """
         subtrack_ratio = self.ratio * ratio
         subtrack_idx = len(self.subtracks) + 1
-        subtrack_name = f"{self.name}_subtrack{subtrack_idx}"
-        subtrack = FeatureSubTrack(
-            subtrack_name, self.size, self.spines, subtrack_ratio
-        )
+        if name is None:
+            name = f"{self.name}_subtrack{subtrack_idx}"
+        if name in [t.name for t in self.subtracks]:
+            err_msg = f"subtrack.name='{name}' is already exists."
+            raise ValueError(err_msg)
+        subtrack = FeatureSubTrack(name, self.size, self.spines, subtrack_ratio)
         self.subtracks.append(subtrack)
 
+    def get_subtrack(self, name: str) -> FeatureSubTrack:
+        """Get subtrack by name
+
+        Parameters
+        ----------
+        name : str
+            Target subtrack name
+
+        Returns
+        -------
+        subtrack : FeatureSubTrack
+            Target subtrack
+        """
+        name2subtrack = {t.name: t for t in self.subtracks}
+        if name not in name2subtrack.keys():
+            err_msg = f"subtrack.name='{name}' is not found."
+            raise ValueError(err_msg)
+        return name2subtrack[name]
+
     def add_feature(
         self,
         start: int,
@@ -539,6 +567,7 @@ class TickTrack(Track):
         """
         super().__init__("tick", size, labelsize, spines, ratio)
         self.tick_style = tick_style
+        self.height_scale = 1.0
 
     @property
     def tick_params(self) -> Dict[str, Any]:
@@ -623,7 +652,7 @@ class TickTrack(Track):
     @property
     def ymin(self) -> float:
         """ymin"""
-        return self.ylim[0] - abs(self.ylim[0] * 0.1)
+        return self.ylim[0] - abs(self.ylim[0] * 0.1 * self.height_scale)
 
     @property
     def ycenter(self) -> float:
@@ -633,7 +662,7 @@ class TickTrack(Track):
     @property
     def ymax(self) -> float:
         """ymax"""
-        return self.ylim[0] + abs(self.ylim[0] * 0.1)
+        return self.ylim[0] + abs(self.ylim[0] * 0.1 * self.height_scale)
 
     @property
     def scalebar_size(self) -> float:
