@@ -3,12 +3,13 @@ from __future__ import annotations
 import csv
 import os
 from dataclasses import dataclass
-from io import TextIOWrapper
+from io import StringIO, TextIOWrapper
 from pathlib import Path
 from typing import List, Optional, Tuple, Union
 from urllib.request import urlretrieve
 
 import matplotlib.pyplot as plt
+import numpy as np
 from Bio import Entrez
 from matplotlib.colors import to_hex
 
@@ -43,6 +44,15 @@ DATASETS = {
         "NC_011750.gbk",
         "link.tsv",
     ],
+    "mycoplasma_gallisepticum": [
+        "NC_004829.gbk",
+        "NC_018407.gbk",
+        "NC_018408.gbk",
+        "NC_018409.gbk",
+        "NC_017502.gbk",
+        "NC_017503.gbk",
+        "link.tsv",
+    ],
 }
 
 
@@ -54,13 +64,14 @@ def load_dataset(
     """Load pygenomeviz example dataset
 
     Download and load datasets from https://github.com/moshi4/pygenomeviz-data
-    and cache datasets in local directory ('~/.cache/pygenomeviz/').
+    and cache datasets in local directory (Default: '~/.cache/pygenomeviz/').
 
     List of dataset name
     - `escherichia_phage`
     - `erwinia_phage`
     - `enterobacteria_phage`
     - `escherichia_coli`
+    - `mycoplasma_gallisepticum`
 
     Parameters
     ----------
@@ -152,13 +163,19 @@ class DatasetLink:
         return links
 
 
-def fetch_genbank_by_accid(accid: str, email: Optional[str] = None) -> TextIOWrapper:
+def fetch_genbank_by_accid(
+    accid: str,
+    gbk_outfile: Optional[Union[str, Path]] = None,
+    email: Optional[str] = None,
+) -> TextIOWrapper:
     """Fetch genbank text by 'Accession ID'
 
     Parameters
     ----------
     accid : str
         Accession ID
+    gbk_outfile : Optional[Union[str, Path]], optional
+        If file path is set, write fetch data to file
     email : str, optional
         Email address to notify download limitation (Required for bulk download)
 
@@ -169,16 +186,23 @@ def fetch_genbank_by_accid(accid: str, email: Optional[str] = None) -> TextIOWra
 
     Examples
     --------
-    >>> gbk_fetch_data = download_genbank_from_accid("JX128258.1")
+    >>> gbk_fetch_data = fetch_genbank_by_accid("JX128258.1")
     >>> gbk = Genbank(gbk_fetch_data)
     """
     Entrez.email = "" if email is None else email
-    return Entrez.efetch(
+    gbk_fetch_data: TextIOWrapper = Entrez.efetch(
         db="nucleotide",
         id=accid,
         rettype="gbwithparts",
         retmode="text",
     )
+    if gbk_outfile is not None:
+        gbk_text = gbk_fetch_data.read()
+        with open(gbk_outfile, "w") as f:
+            f.write(gbk_text)
+        gbk_fetch_data = StringIO(gbk_text)
+
+    return gbk_fetch_data
 
 
 class ColorCycler:
@@ -214,3 +238,28 @@ class ColorCycler:
     def set_cmap(cls, name: str) -> None:
         """Set colormap (Default: `tab10`)"""
         cls.cmap = plt.get_cmap(name)
+        cls.counter = 0
+
+    @classmethod
+    def get_color_list(cls, n: Optional[int] = None) -> List[str]:
+        """Get hexcolor list of colormap
+
+        Parameters
+        ----------
+        n : Optional[int], optional
+            If n is None, all(=cmap.N) hexcolors are extracted from colormap.
+            If n is specified, hexcolors are extracted from n equally divided colormap.
+
+        Returns
+        -------
+        hexcolor_list : List[str]
+            Hexcolor list
+        """
+        if n is None:
+            cmap_idx_list = list(range(0, cls.cmap.N))
+        elif n > 0:
+            cmap_idx_list = [int(i) for i in np.linspace(0, cls.cmap.N, n)]
+        else:
+            raise ValueError(f"n={n} is invalid number (Must be 'n > 0').")
+
+        return [to_hex(cls.cmap(i), keep_alpha=True) for i in cmap_idx_list]
